@@ -136,7 +136,7 @@ class CLI(cl1.CLI):
 
 		# list aliases.
 		elif self.arguments.present("--list-aliases"):
-			array = Files.Array(array=ssht00ls.aliases.list())
+			array = Array(array=ssht00ls.aliases.list())
 			if JSON:
 				print(array.array)
 			else:
