@@ -281,7 +281,7 @@ class Aliases(object):
 		for alias in list(CONFIG["aliases"].keys()):
 			info = CONFIG["aliases"][alias]
 			if "example.com " not in alias:
-				checked = Files.Dictionary(path=False, dictionary=info).check(default={
+				checked = Dictionary(path=False, dictionary=info).check(default={
 					"user":None,
 					"public_ip":None,
 					"private_ip":None,
@@ -343,7 +343,7 @@ class Aliases(object):
 							else:
 								CONFIG["aliases"][alias]["passphrase"] = response.encrypted.decode()
 							utils.save_config_safely()
-				response = self.create(save=False, checks=False, serialized=Files.Dictionary(dictionary=checked).append({"alias":alias}))
+				response = self.create(save=False, checks=False, serialized=Dictionary(dictionary=checked).append({"alias":alias}))
 				if not response["success"]: return response
 				aliases += response["str"]
 				c += 1
