@@ -77,7 +77,7 @@ cache = syst3m.cache.Cache(
 
 # files.
 DATABASE = Files.Directory(path=f"{HOME}/.{ALIAS}")
-CONFIG = Files.Dictionary(path=syst3m.env.fill(syst3m.env.get_string("SSHT00LS_CONFIG", default=DATABASE.join("config",""))), load=True)
+CONFIG = Dictionary(path=syst3m.env.fill(syst3m.env.get_string("SSHT00LS_CONFIG", default=DATABASE.join("config",""))), load=True)
 
 # netw0rk settings.
 IPINFO_API_KEY = os.environ.get("IPINFO_API_KEY")
