@@ -137,7 +137,7 @@ class SCP(object):
 
 		# check fails.
 		if "No such file or directory" in output:
-			response["error"] = f"The base path [{Formats.FilePath(server_path).base()}] of the specified file does not exist on the server."
+			response["error"] = f"The base path [{FilePath(server_path).base()}] of the specified file does not exist on the server."
 			return response
 		elif "not a regular file" in output:
 			response["error"] = f"Client path [{client_path}] is a directory."
