@@ -178,10 +178,10 @@ class SSHD(object):
 
 		# save sshd.
 		if save:
-			file = Files.File(path='/tmp/sshd_config', data=configuration)
+			file = File(path='/tmp/sshd_config', data=configuration)
 			file.file_path.delete(forced=True, sudo=True)
 			file.save()
-			fp = Formats.FilePath(f"/etc/ssh/sshd_config")
+			fp = FilePath(f"/etc/ssh/sshd_config")
 			file.file_path.copy(fp.path, sudo=True)
 			fp.permission.set(permission=644, sudo=True)
 			fp.ownership.set(owner="root", group=None, sudo=True)
@@ -197,7 +197,7 @@ class SSHD(object):
 		#
 	# system functions.
 	def __sum_list__(self, list):
-		return Files.Array(path=False, array=list).string(joiner=',')
+		return Array(path=False, array=list).string(joiner=',')
 	def __convert_boolean__(self, boolean):
 		if boolean: return "yes"
 		else: return "no"
@@ -241,7 +241,7 @@ class SSHD(object):
 		for username in usernames:
 			
 			# non existant.
-			fp = Formats.FilePath(f"{HOME_BASE}{username}/.ssh/utils/.version")
+			fp = FilePath(f"{HOME_BASE}{username}/.ssh/utils/.version")
 			if not fp.exists(sudo=True): 
 				to_install.append(username)
 
@@ -293,7 +293,7 @@ class SSHD(object):
 				if response["error"] != None: return response
 
 			# copy.
-			fp = Formats.FilePath(f"{HOME_BASE}{username}/.ssh/utils/")
+			fp = FilePath(f"{HOME_BASE}{username}/.ssh/utils/")
 			os.system(f"sudo rm -fr {fp.path}")
 			os.system(f"sudo cp -r {path} {fp.path}")
 			fp.ownership.set(owner=username, group=None, sudo=True)
@@ -313,13 +313,13 @@ class SSHD(object):
 			return r3sponse.error("No usernames specified.")
 
 		# save banner.
-		file = Files.File(path='/tmp/banner', data=banner)
+		file = File(path='/tmp/banner', data=banner)
 		file.file_path.delete(forced=True, sudo=True)
 		file.save()
 
 		# iterate.
 		for username in usernames:
-			fp = Formats.FilePath(f"/{HOME_BASE}{username}/.ssh/banner")
+			fp = FilePath(f"/{HOME_BASE}{username}/.ssh/banner")
 			file.file_path.copy(fp.path, sudo=True)
 			fp.permission.set(permission=755, sudo=True)
 			fp.ownership.set(owner=username, group=None, sudo=True)
