@@ -31,7 +31,7 @@ class SSHFS(object):
 		# checks.
 		base = ""
 		if alias == None:
-			success, response = utils.__check_parameters__(empty_value=None, parameters={
+			response = r3sponse.check_parameters(empty_value=None, parameters={
 				"username":username,
 				"ip":ip,
 				"server_path":server_path,
@@ -39,15 +39,15 @@ class SSHFS(object):
 				"key_path":key_path,
 				"port":port,
 			})
-			if not success: return response
+			if not response["success"]: return response
 			base += f"sshfs -p {port} -o IdentityFile={key_path} {username}@{ip}"
 		else:
-			success, response = utils.__check_parameters__(empty_value=None, parameters={
+			response = r3sponse.check_parameters(empty_value=None, parameters={
 				"alias":alias,
 				"server_path":server_path,
 				"client_path":client_path,
 			})
-			if not success: return response
+			if not response["success"]: return response
 			base += f'sshfs {alias}'
 
 		# do.
@@ -91,8 +91,8 @@ class SSHFS(object):
 	):
 
 		# checks.
-		success, response = utils.__check_parameter__(client_path, "client_path", None)
-		if not success: return response
+		response = r3sponse.check_parameters(client_path, "client_path", None)
+		if not response["success"]: return response
 		command = []
 		if sudo: command.append("sudo")
 		command += ["umount"]
