@@ -94,7 +94,7 @@ class SSync(object):
 					return r3sponse.error(f"Failed to create directory {alias}:{remote}, error: {response['error']}")
 
 		# start daemon.
-		cache.set(id=cache_path, group="daemons", data=f"*running* (timestamp={Formats.Date().seconds_timestamp})")
+		cache.set(id=cache_path, group="daemons", data=f"*running* (timestamp={Date().seconds_timestamp})")
 		self.set_mounted_icon(path)
 		if not self.daemons.running(cache_path):
 			return r3sponse.error(f"Failed to set the {path} daemon status.")
@@ -400,7 +400,7 @@ class SSync(object):
 		serialized={},
 	):
 		if serialized != {}:
-			alias, remote, path, start, mode, log_level, sandbox, sleeptime = Files.Dictionary(path=False, dictionary=serialized).unpack({
+			alias, remote, path, start, mode, log_level, sandbox, sleeptime = Dictionary(path=False, dictionary=serialized).unpack({
 				"alias":None,
 				"remote":None,
 				"path":None,
