@@ -14,7 +14,7 @@ def sync():
 	if not dir.fp.exists(): dir.create()
 	for path in dir.paths(recursive=False):
 		removed = False
-		fp = Formats.FilePath(gfp.name(path=path).replace("\\","/"))
+		fp = FilePath(gfp.name(path=path).replace("\\","/"))
 		if not fp.exists(): 
 			os.system(f"rm -fr {path}")
 			removed = True
@@ -35,7 +35,7 @@ def running(path):
 	# check stamp.
 	if "timestamp=" in status:
 		timestamp = status.split("(timestamp=")[1].split(")")[0]
-		date = Formats.Date()
+		date = Date()
 		decreased = date.decrease(date.seconds_timestamp, seconds=SSYNC_DAEMON_SLEEPTIME*5, format=date.seconds_timestamp_format)
 		if date.compare(current=decreased, comparison=timestamp, format=date.seconds_timestamp_format) in ["past", "present"]:
 			return False
@@ -63,7 +63,7 @@ def list(filter=None):
 	dir = Files.Directory(path=f"{cache.path}/daemons/")
 	listed = []
 	for path in dir.paths(recursive=False):
-		fp = Formats.FilePath(gfp.name(path=path).replace("\\","/"))
+		fp = FilePath(gfp.name(path=path).replace("\\","/"))
 		listed.append(fp.path)
 	return listed
 
@@ -180,7 +180,7 @@ class Daemon(syst3m.objects.Thread):
 			if do:
 				status = str(cache.get(id=self.cache_path, group="daemons"))
 				if "*running*" in status:
-					cache.set(id=self.cache_path, group="daemons", data=f"*running* (timestamp={Formats.Date().seconds_timestamp})")
+					cache.set(id=self.cache_path, group="daemons", data=f"*running* (timestamp={Date().seconds_timestamp})")
 
 			# sleep.
 			time.sleep(self.sleeptime)
@@ -756,7 +756,7 @@ class Daemon(syst3m.objects.Thread):
 					if self.log_level >= 0: loader = f"Synchronizing {c} file(s)."
 					msg = f"Successfully synchronized {c} file(s)."
 					error = f"Failed to synchronize {c} file(s)."
-					command = Files.Array(array=batch).string(joiner=" & ")
+					command = Array(array=batch).string(joiner=" & ")
 					response = self.utils.execute(command=command, error=error, message=msg, loader=loader)
 					if not response.success:
 						response = self.utils.execute(command=command, error=error, message=msg, loader=loader)
@@ -807,7 +807,7 @@ class Daemon(syst3m.objects.Thread):
 				if self.log_level >= 0: loader = f"Synchronizing {c} file(s)."
 				msg = f"Successfully synchronized {c} file(s)."
 				error = f"Failed to synchronize {c} file(s)."
-				command = Files.Array(array=commands).string(joiner=" && ")
+				command = Array(array=commands).string(joiner=" && ")
 				response = self.utils.execute(command=command, error=error, message=msg, loader=loader)
 				if not response.success:
 					response = self.utils.execute(command=command, error=error, message=msg, loader=loader)
