@@ -8,7 +8,7 @@ from r3sponse import r3sponse
 
 # index.
 def index(path):
-	indexed, dir, ids = Files.Dictionary(path=False, dictionary={}), Files.Directory(path=path), []
+	indexed, dir, ids = Dictionary(path=False, dictionary={}), Files.Directory(path=path), []
 	for _path_ in dir.paths(recursive=True, files_only=True, banned=[gfp.clean(f"{path}/Icon\r")], banned_names=[".DS_Store", "__pycache__"]):
 		if _path_ not in ids and "/__pycache__/" not in path and "/.DS_Store" not in path: 
 			indexed[_path_] = gfp.mtime(path=_path_, format="seconds")
