@@ -33,7 +33,7 @@ def serialize_path(path, append_last_slash=False):
 def size(path, alias=None, log_level=0):
 	if alias == None:
 		return r3sponse.success(f"Successfully retrieved the size of {path}.", {
-			"size":Formats.FilePath(path).size(mode="MB"),
+			"size":FilePath(path).size(mode="MB"),
 		})
 	else:
 		return execute(
@@ -114,7 +114,7 @@ def pull(
 			tested = True
 
 	# check base.
-	base = Formats.FilePath(path).base(back=1)
+	base = FilePath(path).base(back=1)
 	if not os.path.exists(base): 
 		os.system(f"mkdir -p {base}")
 		if not os.path.exists(base): 
@@ -127,12 +127,12 @@ def pull(
 		os.system(f"mkdir -p {path}")
 
 	# options.
-	exclude_str = Files.Array(array=exclude).string(joiner=" --exclude ", sum_first=True)
-	include_str = Files.Array(array=include).string(joiner=" --include ", sum_first=True)
-	delete_str = Formats.Boolean(delete).convert(true="--delete", false="")
+	exclude_str = Array(array=exclude).string(joiner=" --exclude ", sum_first=True)
+	include_str = Array(array=include).string(joiner=" --include ", sum_first=True)
+	delete_str = Boolean(delete).convert(true="--delete", false="")
 	lremote = serialize_path(gfp.clean(remote), append_last_slash=directory)
 	lpath = serialize_path(gfp.clean(path), append_last_slash=directory)
-	_command_ = f"rsync -{Formats.Boolean(directory).convert(true='a', false='')}zqt '{alias}:{lremote}' '{lpath}' {exclude_str} {include_str} {delete_str} --timeout={SSH_TIMEOUT}"
+	_command_ = f"rsync -{Boolean(directory).convert(true='a', false='')}zqt '{alias}:{lremote}' '{lpath}' {exclude_str} {include_str} {delete_str} --timeout={SSH_TIMEOUT}"
 	#_command_ = f"rsync -azqtr '{alias}:{lremote}' '{lpath}' {exclude_str} {include_str} {delete_str}"
 
 	# execute.
@@ -202,7 +202,7 @@ def push(
 		#if not response["success"]: return response
 		response = ssh.utils.test_ssht00ls(alias=alias, accept_new_host_keys=accept_new_host_keys)
 		if not response.success: return response
-		response = ssh.utils.test_ssh_path(alias=alias, path=Formats.FilePath(remote).base(), accept_new_host_keys=accept_new_host_keys)
+		response = ssh.utils.test_ssh_path(alias=alias, path=FilePath(remote).base(), accept_new_host_keys=accept_new_host_keys)
 		if not response.success: return response
 
 		# dir.
@@ -212,18 +212,18 @@ def push(
 
 	# check remote base.
 	# must be excluded from the checks == False.
-	base = Formats.FilePath(remote).base(back=1)
+	base = FilePath(remote).base(back=1)
 	response = ssh.utils.test_ssh_dir(alias=alias, path=base, accept_new_host_keys=accept_new_host_keys, create=True, checks=False)
 	if not response.success: return response
 	if response.created and log_level >= 3: print(f"Created remote directory {base}.")
 
 	# options.
-	exclude_str = Files.Array(array=exclude).string(joiner=" --exclude ", sum_first=True)
-	include_str = Files.Array(array=include).string(joiner=" --include ", sum_first=True)
-	delete_str = Formats.Boolean(delete).convert(true="--delete", false="")
+	exclude_str = Array(array=exclude).string(joiner=" --exclude ", sum_first=True)
+	include_str = Array(array=include).string(joiner=" --include ", sum_first=True)
+	delete_str = Boolean(delete).convert(true="--delete", false="")
 	lremote = serialize_path(gfp.clean(remote), append_last_slash=directory)
 	lpath = serialize_path(gfp.clean(path), append_last_slash=directory)
-	_command_ = f"rsync -{Formats.Boolean(directory).convert(true='a', false='')}zqt '{lpath}' '{alias}:{lremote}' {exclude_str} {include_str} {delete_str} --timeout={SSH_TIMEOUT}"
+	_command_ = f"rsync -{Boolean(directory).convert(true='a', false='')}zqt '{lpath}' '{alias}:{lremote}' {exclude_str} {include_str} {delete_str} --timeout={SSH_TIMEOUT}"
 	#_command_ = f"rsync -azqtr --rsh=ssh '{lpath}' '{alias}:{lremote}' {exclude_str} {include_str} {delete_str}"
 	
 	# execute.
