@@ -5,5 +5,5 @@ if not os.path.exists(path):
 	r3sponse.log(response=r3sponse.error(f"Path {path} does not exist."))
 else:
 	r3sponse.log(response=r3sponse.success(f"Successfully retrieved the size of {path}.", {
-		"size":Formats.FilePath(path).size(mode="MB"),
+		"size":FilePath(path).size(mode="MB"),
 	}))
\ No newline at end of file
